#!/bin/sh

# All Rights Reserved.
# Copyright (C) 2006,2018, Hitachi, Ltd.
############################################################
# Functions

# Answer check subroutine
chk_YesNo()
{
    while [ 1 ]
    do
        echo -n "(y|n[n]) : "
        read ANS
        case $ANS in
          Y|y)
            return 0
            ;;
          N|n|*)
            return 1
            ;;
        esac
    done
}

get_conffile()
{
	local SEC="$1"
	local KEY="$2"
	local FILE="$3"
	
	sed -n "/^\\[${SEC}\\]/,/^\\[/p" ${FILE} | grep "^${KEY}=" | cut -f2 -d=
}
set_conffile()
{
	local SEC="$1"
	local KEY="$2"
	local VAL="$3"
	local FILE="$4"
	local TEMP_FILE=${FILE}.tmp

	grep -q "^\\[${SEC}\\]" ${FILE}
	if [ $? -eq 0 ]; then
		sed -n "/^\\[${SEC}\\]/,/^\\[/p" ${FILE} | grep -q "^${KEY}="
		if [ $? -eq 0 ]; then
			sed "/^\\[${SEC}\\]/,/^\\[/s/^${KEY}=.*$/${KEY}=${VAL//\//\\/}/" ${FILE} > ${TEMP_FILE}
		else
			sed "/^\\[${SEC}\\]/a ${KEY}=${VAL}" ${FILE} > ${TEMP_FILE}
		fi
		[ $? -eq 0 ] && mv -f ${TEMP_FILE} ${FILE}
		rm -f ${TEMP_FILE}
	else
		echo "[${SEC}]" >> ${FILE}
		echo "${KEY}=${VAL}" >> ${FILE}
	fi
}

copy_conffile()
{
	local OLDFILE="$1"
	local NEWFILE="$2"
	local SECKEYS="$3"
	
	if [ -f ${OLDFILE} ]; then
		IFS=","
		for SECKEY in ${SECKEYS}
		do
			IFS=:
			FLDS=(${SECKEY})
			KEYVALUE=`get_conffile ${FLDS[0]} ${FLDS[1]} ${OLDFILE}`
			if [ -n "${KEYVALUE}" ]; then
				set_conffile ${FLDS[0]} ${FLDS[1]} ${KEYVALUE} ${NEWFILE}
			fi
		done
	fi
}

############################################################
# Main function
PRODUCT_NAME=MIACAT
echo
echo "--------------------------------------------------------------"
echo " ${PRODUCT_NAME} Setup tool."
echo "   All Rights Reserved. Copyright (C) 2006,2017, Hitachi, Ltd."
echo "--------------------------------------------------------------"
echo

if [ `whoami` != "root" ]
then
    echo "Failed."
    echo "You are not root user."
    echo "Installation was canceled."
    exit 1
fi

INST_DIR="/opt/hitachi/miacat"
RC_FILE=smal2d
RC_FILE_TO=/etc/init.d/${RC_FILE}
CONFFILE=/opt/hitachi/miacat/MainteData/smal2.conf

if [ -d ${INST_DIR} ]
then
    if [ ! -f ${RC_FILE_TO} ]
    then
        echo "'${PRODUCT_NAME}' is not installed."
        echo "Setup was canceled."
        exit 1
    fi
    
    if [ ! -f ${CONFFILE} ]
    then
        echo "'${PRODUCT_NAME}' is not installed."
        echo "Setup was canceled."
        exit 1
    fi
fi

##############################
# Select Server Model
BLADE_TYPE=
BLADE_TYPE_NAME=

echo "Please choose Server Model of the use."
echo " 1. BS320 / CB320"
echo " 2. BS500 / CB500 / BS2500 / CB2500"
echo " 3. BS2000 / CB2000"
echo
while [ 1 ]
do
    echo -n "(1-3,q) : "
    read ANS
    case $ANS in
      1)
        BLADE_TYPE="320"
        BLADE_TYPE_NAME="BS320 / CB320"
        break
        ;;
      2)
        BLADE_TYPE="500"
        BLADE_TYPE_NAME="BS500 / CB500 / BS2500 / CB2500"
        break
        ;;
      3)
        BLADE_TYPE="2000"
        BLADE_TYPE_NAME="BS2000 / CB2000"
        break
        ;;
      q|Q)
        echo "Setup was canceled."
        exit 1
        ;;
    esac
done

##############################
# Connection Server.
#echo
#echo "Set Connection Server."
#
#while [ 1 ]
#do
#	echo -n " Server IP Address  : "
#	read SRVIPADD
#
#    case $SRVIPADD in
#      q|Q)
#        echo "Setup was canceled."
#        exit 1
#        ;;
#    esac
#
#	if [ `expr "$SRVIPADD" : "[0-9]*\.[0-9]*\.[0-9]*\.[0-9]*"` -eq `expr "$SRVIPADD" : ".*"` ]
#	then
#		break
#	fi
#done
#
#while [ 1 ]
#do
#	echo -n " ID                 : "
#	read SRVID
#
#	if [ ! -z "${SRVID}" ]; then
#		break
#	fi
#done
#
#while [ 1 ]
#do
#	while [ 1 ]
#	do
#		echo -n " PASSWORD           : "
#		read -s SRVPASSWD
#		echo
#		if [ ! -z "${SRVPASSWD}" ]; then
#			break
#		fi
#	done
#	
#	while [ 1 ]
#	do
#		echo -n " Retry PASSWORD     : "
#		read -s SRVPASSWD2
#		echo
#		if [ ! -z "${SRVPASSWD2}" ]; then
#			break
#		fi
#	done
#
#	if [ $SRVPASSWD = $SRVPASSWD2 ]; then
#    	break
#  	else
#  		
#		echo 
#		echo " Sorry. PASSWORD do not match."
#		echo 
#  	fi
#done
#
###############################################
# confirm

echo
echo "Confirm Data. "
echo " Server Model : ${BLADE_TYPE_NAME}"
#echo " Server IP Address : ${SRVIPADD}"
#echo " ID                : ${SRVID}"
#echo " PASSWORD          : ********"

echo
echo "Do you update this configuration ?"

if ! chk_YesNo
then
	echo
    echo "Setup was canceled."
    echo
    exit 1
fi

###############################################
# Set Data.
CONFFILE=/opt/hitachi/miacat/MainteData/smal2.conf
SET_SEC='SOFTWARE\\Hitachi\\miacat'
SET_KEY="SystemID"
SET_BS320="0x0000000b"
SET_BS500="0x1000000b"
SET_BS2000="0x1000000b"
SETSERVERINFO=/opt/hitachi/tools/miacat/setServerInfo
VMSYSLOG_FILE=/var/opt/hitachi/VmSyslogMAgtSrvd/log/vmsyslog_MAgtSrv

if [ $BLADE_TYPE = "320" ] 
then
	set_conffile $SET_SEC $SET_KEY $SET_BS320 $CONFFILE
fi
if [ $BLADE_TYPE = "500" ] 
then
	set_conffile $SET_SEC $SET_KEY $SET_BS500 $CONFFILE
fi
if [ $BLADE_TYPE = "2000" ] 
then
	set_conffile $SET_SEC $SET_KEY $SET_BS2000 $CONFFILE
fi

#############################
# tbl file update
for MSGDIR in ${INST_DIR}/MainteData/basetbl/${BLADE_TYPE}/*
do
	if [ -f ${MSGDIR} ]; then
		 ${INST_DIR}/Program/tblupdate -u ${MSGDIR} -s -N > /dev/null 2>&1
	fi
done

#${SETSERVERINFO} Set -s $SRVIPADD -u $SRVID -p $SRVPASSWD > /dev/null 2>&1
#if [ $? -ne 0 ]; then
#	echo
#    echo "Setup Failed. Abnormal End. "
#    echo
#    exit 1
#fi

RC_FILE=smal2d
RC_FILE_TO=/etc/init.d/${RC_FILE}

/usr/lib/lsb/install_initd /etc/init.d/VmSyslogMAgtSrvd  > /dev/null 2>&1
/usr/lib/lsb/install_initd ${RC_FILE_TO}  > /dev/null 2>&1

SMAL2MASVCPID=/var/run/SMAL2MASvc.pid
if [ -f ${SMAL2MASVCPID} ] ; then
	echo "Do you restart agent program?"

	if chk_YesNo
	then
		/etc/init.d/VmSyslogMAgtSrvd restart
		/etc/init.d/smal2d restart
	fi
else
	echo "Do you start agent program?"

	if chk_YesNo
	then
		/etc/init.d/VmSyslogMAgtSrvd start

		echo -n "Please wait for a while."
		
		while [ 1 ]
		do
		
		    if [ ! -f ${VMSYSLOG_FILE} ]
		    then
		        echo -n "."
		        sleep 1
		    else
		    	echo ""
		    	break
		    fi
		done

		/etc/init.d/smal2d start
	fi
fi

echo
echo "Setup was completed."
echo

exit 0
